@@ -1,12 +1,9 @@
-use 5.006;
-use strict;
-use warnings;
+use 5.006; use strict; use warnings;
 
 package Test::Lives;
-$Test::Lives::VERSION = '1.001';
-# ABSTRACT: the 1UP approach to testing exceptional code
+$Test::Lives::VERSION = '1.002';
+# ABSTRACT: decorate tests with a no-exceptions assertion
 
-use Exporter::Tidy default => [ qw( lives_and ) ];
 use Test::Builder ();
 
 my $Tester = Test::Builder->new;
@@ -21,6 +18,7 @@ sub lives_and (&;$) {
 
 	eval {
 		local $Level = $Level + 2; # eval block + callback
+		local $Carp::Internal{(__PACKAGE__)} = 1;
 		$ok = $code->() for $name;
 		1;
 	} or do {
@@ -32,6 +30,13 @@ sub lives_and (&;$) {
 	return $ok;
 }
 
+sub import {
+	my $class = shift;
+	do { die "Unknown symbol: $_" if $_ ne 'lives_and' } for @_;
+	no strict 'refs';
+	*{ caller . '::lives_and' } = \&lives_and;
+}
+
 1;
 
 __END__
@@ -42,11 +47,11 @@ __END__
 
 =head1 NAME
 
-Test::Lives - the 1UP approach to testing exceptional code
+Test::Lives - decorate tests with a no-exceptions assertion
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -59,46 +64,28 @@ version 1.001
 
 =head1 DESCRIPTION
 
-This module provides only one function, C<lives_and>, which allows you to test
-things that could (but shouldn't) throw an exception, without having to have
+This module provides only one function, C<lives_and>, which works almost
+exactly like the function of the same name in L<Test::Exception>. That is,
+it allows you to test things that could (but shouldn't) throw an exception
+without having to have
 two separate tests with two separate results (and two separate descriptions).
 
 You pass it a block of code to run (which should contain one test assertion)
 and a test description to give the assertion inside the block.
 
 The description will be available inside the block in the C<$_> variable.
+(This is different from L<Test::Exception>, which employs hacky magic to
+relieve you of having to pass the description to the decorated assertion.)
 
 If the block ends up throwing an exception, a test failure will be logged.
 
-=head1 BUGS AND LIMITATIONS
-
-Currently this module is written against the traditional, singleton-based
-Test::Builder design only. It should also have an implementation appropriate
-for newer Test::Builder versions, and pick between them at runtime. But that
-is not yet implemented.
-
-=head1 SEE ALSO
-
-=over 4
-
-=item * L<Test::Exception>
-
-The original perpetrator of the C<lives_and> design as an assertion decorator.
-Unfortunately it has grown several questionable dependencies.
-
-=item * L<Test::Fatal>
-
-Recommended for any exception-related testing needs beyond C<lives_and>.
-
-=back
-
 =head1 AUTHOR
 
 Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Aristotle Pagaltzis.
+This software is copyright (c) 2017 by Aristotle Pagaltzis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
